@@ -20,6 +20,7 @@
 #' @param jitter Amount to use to slightly adjust locations so that multiple
 #' monitors at the same location can be seen. Use zero or \code{NA} to see
 #' precise locations.
+#' @param NAAQS Version of NAAQS levels to use. See Note.
 #' @param ... Additional arguments passed to \code{leaflet::addCircleMarker()}.
 #'
 #' @description
@@ -39,7 +40,7 @@
 #' The \code{maptype} argument is mapped onto leaflet "ProviderTile" names.
 #' Current map types include:
 #'
-#' \enumerate{
+#' \describe{
 #' \item{"roadmap"}{ -- "OpenStreetMap"}
 #' \item{"satellite"}{ -- "Esri.WorldImagery"}
 #' \item{"terrain"}{ -- "Esri.WorldTopoMap"}
@@ -51,6 +52,18 @@
 #' \url{https://leaflet-extras.github.io/leaflet-providers/} for a list of
 #' "provider tiles" to use as the background map.
 #'
+#' @note
+#' On February 7, 2024, EPA strengthened the National Ambient Air Quality
+#' Standards for Particulate Matter (PM NAAQS) to protect millions of Americans
+#' from harmful and costly health impacts, such as heart attacks and premature
+#' death. Particle or soot pollution is one of the most dangerous forms of air
+#' pollution, and an extensive body of science links it to a range of serious
+#' and sometimes deadly illnesses. EPA is setting the level of the primary
+#' (health-based) annual PM2.5 standard at 9.0 micrograms per cubic meter to
+#' provide increased public health protection, consistent with the available
+#' health science.
+#' See \href{https://www.epa.gov/pm-pollution/final-reconsideration-national-ambient-air-quality-standards-particulate-matter-pm}{PM NAAQS update}.
+#'
 #' @return Invisibly returns a leaflet map of class "leaflet".
 #'
 #' @examples
@@ -59,10 +72,26 @@
 #' # Fail gracefully if any resources are not available
 #' try({
 #'
+#' # Maximum AQI category at each site
 #' monitor_loadLatest() %>%
 #'   monitor_filter(stateCode %in% CONUS) %>%
 #'   monitor_leaflet()
 #'
+#' # Mean AQI category at each site
+#' monitor_loadLatest() %>%
+#'   monitor_filter(stateCode %in% CONUS) %>%
+#'   monitor_leaflet(
+#'     slice = "mean"
+#'   )
+#'
+#' # Mean AQI category at each site using the updated NAAQS
+#' monitor_loadLatest() %>%
+#'   monitor_filter(stateCode %in% CONUS) %>%
+#'   monitor_leaflet(
+#'     slice = "mean",
+#'     NAAQS = "PM2.5_2024"
+#'   )
+#'
 #' }, silent = FALSE)
 #' }
 
@@ -74,6 +103,7 @@ monitor_leaflet <- function(
   maptype = "terrain",
   extraVars = NULL,
   jitter = 5e-4,
+  NAAQS = c("PM2.5", "PM2.5_2024"),
   ...
 ) {
 
@@ -101,6 +131,8 @@ monitor_leaflet <- function(
     jitter <- 0
   }
 
+  NAAQS = match.arg(NAAQS)
+
   # ----- Pollutant dependent AQI ----------------------------------------------
 
   # See: https://www.airnow.gov/sites/default/files/2020-05/aqi-technical-assistance-document-sept2018.pdf
@@ -133,7 +165,10 @@ monitor_leaflet <- function(
   AQI_colors <- US_AQI[[paste0("colors_", "EPA")]]
   AQI_names <- US_AQI$names_eng
 
-  # TODO:  Figure out how to allow custom breaks, colors and labels
+  # Handle the added NAAQS argument
+  if ( pollutant == "PM2.5" && NAAQS == "PM2.5_2024" ) {
+    AQI_breaks <- US_AQI$breaks_PM2.5_2024
+  }
 
   breaks <- AQI_breaks
   colors <- AQI_colors
